@@ -73,30 +73,30 @@ def translate_metar(wind_string):
   # Initialize output string; assume invalid data
   output_string = "Invalid data!"
   # Obtain integer values from metar string
-  dir, spd, gst = decode_metar_wind(wind_string)
+  direction, spd, gst = decode_metar_wind(wind_string)
   # Check if wind direction is legit
-  if dir >=0 and dir <= 350:
+  if direction >=0 and direction <= 350:
     # Convert wind direction to verbal description.
-    if  dir > 292:
-      verbal_direction = "northwest"
-    elif dir > 247:
-      verbal_direction = "west"
-    elif dir > 202:
-      verbal_direction = "southwest"
-    elif dir > 157:
-      verbal_direction = "south"
-    elif dir > 112:
-      verbal_direction = "southeast"
-    elif dir > 67:
-      verbal_direction = "east"
-    elif dir > 22:
-      verbal_direction = "northeast"
+    if 23 < direction <= 67:
+      wind_direction = "northeast"
+    elif 67 < direction <= 113:
+      wind_direction = "east"
+    elif 113 < direction <= 158:
+      wind_direction = "southeast"
+    elif 158 < direction <= 203:
+      wind_direction = "south"
+    elif 203 < direction <= 248:
+      wind_direction = "southwest"
+    elif 248 < direction <= 293:
+      wind_direction = "west"
+    elif 293 < direction <= 338:
+      wind_direction = "northwest"
     else:
-      verbal_direction = "north"
+      wind_direction = "north"
     # Convert speed from knots to mph and take int() part only
     speed_mph = int(spd*nautical_to_statute_mile)
     # Start building output string
-    output_string = ("Wind is from the " + verbal_direction + 
+    output_string = ("Wind is from the " + wind_direction + 
                      " at " + str(speed_mph) + " miles per hour")
     # Determine gusting information
     if gst is None:
